if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/bin ; rm -rf gnome-help )
( cd usr/bin ; ln -sf yelp gnome-help )
( cd usr/lib64 ; rm -rf libyelp.so )
( cd usr/lib64 ; ln -sf libyelp.so.0.0.0 libyelp.so )
( cd usr/lib64 ; rm -rf libyelp.so.0 )
( cd usr/lib64 ; ln -sf libyelp.so.0.0.0 libyelp.so.0 )
